| generate_sql_strings | R Documentation |
Read all files from path and return a list, where the list elements contain the individual 'SQL' statements and queries as strings
generate_sql_strings(path = "")
path |
A path to a folder or a file containing 'SQL' code |
A list with named elements containing 'SQL' statements as strings
## prepare example file
p <- fs::path(tempdir(), "test-file-001.sql")
fs::file_create(p)
readr::write_lines("
-- name: select_count
select count(*) from tab1;
", p)
## sqlstrings
s <- generate_sql_strings(path = p)
s$select_count
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.